<?php
/**
 * Compact One functions and definitions.
 *
 * @link
 *
 * @package compact-one
 */

namespace Compact\Core;

require_once get_stylesheet_directory() . '/customizer.php';
require_once get_stylesheet_directory() . '/custom-functions.php';

/**
 * Enqueue scripts and styles
 */
function enqueue() {

	$parent_style = 'responsive-style';

	wp_enqueue_style( $parent_style, get_template_directory_uri() . '/core/css/style.css' );
	wp_enqueue_style(
		'compact-style',
		get_stylesheet_directory_uri() . '/style.css',
		array( $parent_style ),
		wp_get_theme()->get( 'Version' )
	);
	$directory_uri = get_stylesheet_directory_uri();

	// Define paths.
	$js_path        = $directory_uri . '/lib/js/';
	$bootstrap_path = $directory_uri . '/lib/bootstrap/';

	// Load Bootstrap Library Items.
	if ( is_front_page() ) {
		wp_enqueue_style( 'bootstrap-style', $bootstrap_path . 'css/bootstrap.min.css', false, '3.3.7' );
		wp_enqueue_script( 'bootstrap-js', $bootstrap_path . 'js/bootstrap.min.js', array( 'jquery' ), '3.3.7', false );

		wp_enqueue_style( 'animate-style', $directory_uri . '/css/animate.css', false, '3.5.1' );

		wp_enqueue_script( 'waypoints', $directory_uri . '/js/jquery.waypoints.min.js', '', '', false );
		wp_enqueue_script( 'jquerycountup', $directory_uri . '/js/jquery.counterup.js', '', '', false );

		if ( is_page_template( 'template-home.php' ) ) {
			wp_enqueue_script( 'script-wow', $directory_uri . '/js/wow.min.js' );
            wp_enqueue_script( 'compact_one_custom_js', $directory_uri . '/js/custom.js', array( 'jquery' ), '', true );

        }
		wp_enqueue_script( 'jquery-easing', $directory_uri . '/js/jquery.easing.min.js', array( 'jquery' ), '' );
		wp_enqueue_script( 'jquery-scrolling-nav', $directory_uri . '/js/scrolling-nav.js', array( 'jquery' ), '' );
		wp_enqueue_script( 'isotope-main', $directory_uri . '/js/isotope.pkgd.min.js', array( 'jquery' ), '', false );
		wp_enqueue_style( 'roboto-font', '//fonts.googleapis.com/css?family=Roboto:400,400i,500,700', false );
		wp_enqueue_style( 'lato-font', '//fonts.googleapis.com/css?family=Lato:400,700', false );
		wp_enqueue_style( 'fontawesome-style', $directory_uri . '/css/font-awesome.min.css', false, '4.7.0' );

		// Load library for jcarousel.
		wp_enqueue_script( 'jcarousel', $js_path . 'jquery.jcarousel.min.js', array( 'jquery' ), '1.0' );

		// elements css enqueued for css such as portfolio popup.
		wp_enqueue_style( 'elements_style', $directory_uri . '/lib/css/elements.css' );

		// Load JS for slimbox.
		wp_enqueue_script( 'slimbox', $js_path . 'jquery.slimbox.min.js', array( 'jquery' ), '1.0' );

		// touch swipe gestures.
		wp_enqueue_script( 'jquery-mobile-touch', $js_path . 'jquery.mobile.custom.min.js', array( 'jquery' ) );
		wp_enqueue_script( 'slider-call', $js_path . 'swipe-call.min.js', array( 'jquery', 'jquery-mobile-touch' ) );

		// Load core JS.
		wp_enqueue_script( 'cyberchimps-core-js', $js_path . 'core.min.js', array( 'jquery' ) );

		// Load Core Stylesheet.
		wp_enqueue_style( 'core-style', $directory_uri . '/lib/css/core.css', array( 'bootstrap-style' ), '1.0' );

		// Load Theme Stylesheet.
		wp_enqueue_style( 'style', get_stylesheet_uri(), array( 'core-style' ), '1.0' );
		wp_enqueue_script( 'video', $js_path . 'video.min.js' );

	}

}
add_action( 'wp_enqueue_scripts', 'Compact\Core\enqueue', 99 );

require get_stylesheet_directory() . '/custom-compact-styles.php';

/**
 * Function to register multiple checkboxes option
 */
function compact_one_load_customize_controls() {

	require_once trailingslashit( get_stylesheet_directory() ) . 'control-checkbox-multiple.php';
}
add_action( 'customize_register', 'Compact\Core\compact_one_load_customize_controls', 0 );

/**
 * This function overrides customizer defaults of Responsive theme
 *
 * @param array $theme_options Theme Options.
 * @return mixed
 */
function override_theme_defaults( $theme_options ) {
	$theme_color = get_theme_mod( 'compact_theme_color', '#3a6591' );

	$theme_options['header_background']                   = 'rgba(58, 101, 145, 0.9)';
	$theme_options['header_menu_background']              = 'rgba(58, 101, 145, 0.9)';
	$theme_options['link']                                = '#337ab7';
	$theme_options['header_menu_link']                    = '#ffffff';
	$theme_options['header_menu_link_hover']              = '#ffffff';
	$theme_options['header_active_menu_background']       = 'transparent';
	$theme_options['header_menu_toggle']                  = '#fff';
	$theme_options['header_site_title']                   = '#ffffff';
	$theme_options['header_text']                         = '#ffffff';
	$theme_options['body_text']                           = '#000000';
	$theme_options['shop_product_price']                  = $theme_color;
	$theme_options['button']                              = $theme_color;
	$theme_options['button_hover']                        = $theme_color;
	$theme_options['button_hover_text']                   = '#0066CC';
	$theme_options['add_to_cart_button']                  = $theme_color;
	$theme_options['scroll_to_top_icon']                  = '#fff';
	$theme_options['scroll_to_top_icon_hover']            = '#fff';
	$theme_options['scroll_to_top_icon_background']       = $theme_color;
	$theme_options['scroll_to_top_icon_background_hover'] = $theme_color;
	$theme_options['theme']                               = $theme_color;

	$theme_options['read_more_text']            = 'Read More';
	$theme_options['breadcrumb_alignment']      = 'left';
	$theme_options['page_content_width']        = 75;
	$theme_options['blog_content_width']        = 75;
	$theme_options['single_blog_content_width'] = 75;
	$theme_options['footer_text']               = '#b2babd';
	$theme_options['footer_links']              = '#9b9c9b';
	$theme_options['footer_links_hover']        = '#9b9c9b';
	$theme_options['box_padding']               = 0;
	$theme_options['entry_columns']             = 2;
	$theme_options['buttons_radius']            = 20;
	$theme_options['background_color']          = '#fff';
	$theme_options['blog_entry_elements_positioning']          =  array( 'featured_image', 'title', 'meta', 'content' );
	$theme_options['blog_single_elements_positioning']          =  array( 'featured_image', 'title', 'meta', 'content' );


	return $theme_options;
}
add_filter( 'responsive_theme_defaults', 'Compact\Core\override_theme_defaults', 10, 1 );

/**
 * This function overrides responsive_theme_footer_link filter
 *
 * @param $footer_link
 */
function get_footer_link( $footer_link ) {
	$footer_link = esc_url( 'https://cyberchimps.com/wordpress-themes/compact/' );

	return $footer_link;
}
add_filter( 'responsive_theme_footer_link', 'Compact\Core\get_footer_link', 10, 1 );

/**
 * This function overrides responsive_theme_footer_link_text filter
 *
 * @param $footer_link_text
 */
function get_footer_link_text( $footer_link_text ) {
	$footer_link_text = esc_html__( ' | Powered by Compact One', 'compact-one' );

	return $footer_link_text;
}
add_filter( 'responsive_theme_footer_link_text', 'Compact\Core\get_footer_link_text', 10, 1 );

/**
 * This function overrides responsive_blog_single_elements_positioning filter
 *
 * @param array $sections Sections.
 */
function override_blog_single_elements_positioning( $sections ) {
	$sections = array( 'featured_image', 'meta', 'title', 'content' );
        $sections = get_theme_mod( 'responsive_blog_single_elements_positioning', $sections );

	return $sections;
}
add_filter( 'responsive_blog_single_elements_positioning', 'Compact\Core\override_blog_single_elements_positioning', 10, 1 );

/**
 * This function overrides responsive_blog_entry_elements_positioning filter
 *
 * @param array $sections Sections.
 */
function override_blog_elements_positioning( $sections ) {
	$sections = array( 'featured_image', 'title', 'meta', 'content' );
    $sections = get_theme_mod( 'responsive_blog_entry_elements_positioning', $sections );

	return $sections;
}
add_filter( 'responsive_blog_entry_elements_positioning', 'Compact\Core\override_blog_elements_positioning', 10, 1 );

/**
 * Styles for header
 */
function compact_one_custom_styles() {
	// check if slider is enabled else modify menu.
	$compact_one_enable_slider_section = get_theme_mod( 'compact_one_enable_slider_section', 1 );
	if ( empty( $compact_one_enable_slider_section ) || ( ! isset( $compact_one_enable_slider_section ) ) ) {
		?>
		<style>
			.site-header
			{
				background: rgba(58, 101, 145, 0.9);
				position: relative;
				margin-top: 0;
			}
			.page-template-template-home .sticky-header2 .navbar-default
			{
				position:fixed;
			}
		</style>
		<?php
	}

}
add_action( 'wp_head', 'Compact\Core\compact_one_custom_styles', 100 );

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook
 */
function compact_one_theme_support() {
	/*
	 * Adds starter content to highlight the theme on fresh sites.
	 * This is done conditionally to avoid loading the starter content on every
	 * page load, as it is a one-off operation only needed once in the customizer.
	 */
	if ( is_customize_preview() ) {
		require __DIR__ . '/inc/starter-content.php';
		add_theme_support( 'starter-content', compact_one_get_starter_content() );
	}

}

add_action( 'after_setup_theme', 'Compact\Core\compact_one_theme_support', 20 );
