<?php
/**
 * Compact One Starter Content
 *
 * @package Compact One
 * @since Compact One 1.9
 */

/**
 * Function to return the array of starter content for the theme.
 *
 * Passes it through the `compact_one_starter_content` filter before returning.
 *
 * @since Compact One 2.0.0
 * @return array a filtered array of args for the starter_content.
 */
function compact_one_get_starter_content() {

	// Define and register starter content to showcase the theme on new sites.
	$starter_content = array(
		'widgets'    => array(
			// Place one core-defined widgets in the first footer widget area.
			'sidebar-1' => array(
				'text_about',
			),
		),

		// Specify the core-defined pages to create and add custom thumbnails to some of them.
		'posts'      => array(
			'front' => array(
				'post_type'    => 'page',
				'post_title'   => __( 'Home', 'compact-one' ),
				'template'     => 'gutenberg-fullwidth.php',
				'post_content' => join(
					'',
					array(
						'<!-- wp:cover {"url":"' . get_theme_file_uri() . '/images/compact-bg.jpg' . '","id":15,"dimRatio":90,"customGradient":"linear-gradient(353deg,rgb(69,163,199) 0%,rgb(58,101,145) 100%)","align":"full"} -->',
						'<div class="wp-block-cover alignfull has-background-dim-90 has-background-dim has-background-gradient" style="background-image:url(' . get_theme_file_uri() . '/images/compact-bg.jpg' . ')">',
						'<span aria-hidden="true" class="wp-block-cover__gradient-background" style="background:linear-gradient(353deg,rgb(69,163,199) 0%,rgb(58,101,145) 100%)"></span>',
						'<div class="wp-block-cover__inner-container">',
						'<!-- wp:spacer {"height":200} -->',
						'<div style="height:200px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:paragraph {"align":"center","placeholder":"Write title…","fontSize":"large"} -->',
						'<p class="has-text-align-center has-large-font-size">SMOOTH SCROLLING MENU</p>',
						'<!-- /wp:paragraph -->',
						'<!-- wp:buttons {"align":"center"} -->',
						'<div class="wp-block-buttons aligncenter">',
						'<!-- wp:button {"backgroundColor":"button-hover-text-color","textColor":"responsive-container-background-color","borderRadius":2,"className":"is-style-fill"} -->',
						'<div class="wp-block-button is-style-fill"><a class="wp-block-button__link has-text-color has-responsive-container-background-color-color has-background has-button-hover-text-color-background-color" style="border-radius:2px">Learn More</a></div>',
						'<!-- /wp:button --></div>',
						'<!-- /wp:buttons -->',
						'<!-- wp:spacer {"height":200} -->',
						'<div style="height:200px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer --></div></div>',
						'<!-- /wp:cover -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:heading {"align":"center","level":1} -->',
						'<h1 class="has-text-align-center">ABOUT US</h1>',
						'<!-- /wp:heading -->',
						'<!-- wp:spacer {"height":30} -->',
						'<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Compact One has detailed&nbsp;step by step video tutorials&nbsp;to help you set up the theme easily. You can also request for this very demo data (content and images) – right from your WordPress Dashboard. Simply import the demo data into your site, watch the videos and set up your new Compact One website.</p>',
						'<!-- /wp:paragraph -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:cover {"customOverlayColor":"#192c33","align":"full"} -->',
						'<div class="wp-block-cover alignfull has-background-dim" style="background-color:#192c33"><div class="wp-block-cover__inner-container">',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:heading {"align":"center","level":1,"textColor":"button-hover-text-color"} -->',
						'<h1 class="has-button-hover-text-color-color has-text-color has-text-align-center">Features</h1>',
						'<!-- /wp:heading -->',
						'<!-- wp:spacer {"height":30} -->',
						'<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:columns -->',
						'<div class="wp-block-columns"><!-- wp:column -->',
						'<div class="wp-block-column">',
						'<!-- wp:image {"align":"center","id":23,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/compact-icon1.png" alt="" class="wp-image-23"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4,"textColor":"button-hover-text-color"} -->',
						'<h4 class="has-button-hover-text-color-color has-text-color has-text-align-center">RESPONSIVE DESIGN</h4>',
						'<!-- /wp:heading -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Lorem ipsum dolor sit amet, consectetur adipisicing elit</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":25,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/compact-icon2.png" alt="" class="wp-image-25"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4,"textColor":"button-hover-text-color"} -->',
						'<h4 class="has-button-hover-text-color-color has-text-color has-text-align-center">EASY TO CUSTOMIZE</h4>',
						'<!-- /wp:heading -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Lorem ipsum dolor sit amet, consectetur adipisicing elit</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":24,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/compact-icon3.png" alt="" class="wp-image-24"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4,"textColor":"button-hover-text-color"} -->',
						'<h4 class="has-button-hover-text-color-color has-text-color has-text-align-center">MULTIPLE ELEMENTS</h4>',
						'<!-- /wp:heading -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Lorem ipsum dolor sit amet, consectetur adipisicing elit</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column --></div>',
						'<!-- /wp:columns -->',
						'<!-- wp:spacer {"height":50} -->',
						'<div style="height:50px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:columns -->',
						'<div class="wp-block-columns"><!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":24,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/compact-icon3.png" alt="" class="wp-image-24"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4,"textColor":"button-hover-text-color"} -->',
						'<h4 class="has-button-hover-text-color-color has-text-color has-text-align-center">CLEAN DESIGN</h4>',
						'<!-- /wp:heading -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Lorem ipsum dolor sit amet, consectetur adipisicing elit</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":25,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/compact-icon2.png" alt="" class="wp-image-25"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4,"textColor":"button-hover-text-color"} -->',
						'<h4 class="has-button-hover-text-color-color has-text-color has-text-align-center">UNLIMITED FEATURES</h4>',
						'<!-- /wp:heading -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Lorem ipsum dolor sit amet, consectetur adipisicing elit</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":23,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/compact-icon1.png" alt="" class="wp-image-23"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4,"textColor":"button-hover-text-color"} -->',
						'<h4 class="has-button-hover-text-color-color has-text-color has-text-align-center">RESPONSIVE</h4>',
						'<!-- /wp:heading -->',
						'<!-- wp:paragraph {"align":"center"} -->',
						'<p class="has-text-align-center">Lorem ipsum dolor sit amet, consectetur adipisicing elit</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column --></div>',
						'<!-- /wp:columns -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer --></div></div>',
						'<!-- /wp:cover -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:heading {"align":"center","level":1} -->',
						'<h1 class="has-text-align-center">Our Portfolio</h1>',
						'<!-- /wp:heading -->',
						'<!-- wp:spacer {"height":30} -->',
						'<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:gallery {"ids":[39,40,41,42,43,44],"linkTo":"media"} -->',
						'<figure class="wp-block-gallery columns-3 is-cropped"><ul class="blocks-gallery-grid">',
						'<li class="blocks-gallery-item"><figure><a href="' . get_theme_file_uri() . '/images/compact-gallery6.jpg"><img src="' . get_theme_file_uri() . '/images/compact-gallery6.jpg" alt="" data-id="39" data-full-url="' . get_theme_file_uri() . '/images/compact-gallery6.jpg" data-link="' . site_url() . '/home/compact-gallery6/" class="wp-image-39"/></a></figure></li>',
						'<li class="blocks-gallery-item"><figure><a href="' . get_theme_file_uri() . '/images/compact-gallery5.jpg"><img src="' . get_theme_file_uri() . '/images/compact-gallery5.jpg" alt="" data-id="40" data-full-url="' . get_theme_file_uri() . '/images/compact-gallery5.jpg" data-link="' . site_url() . '/home/compact-gallery5/" class="wp-image-40"/></a></figure></li>',
						'<li class="blocks-gallery-item"><figure><a href="' . get_theme_file_uri() . '/images/compact-gallery4.jpg"><img src="' . get_theme_file_uri() . '/images/compact-gallery4.jpg" alt="" data-id="41" data-full-url="' . get_theme_file_uri() . '/images/compact-gallery4.jpg" data-link="' . site_url() . '/home/compact-gallery4/" class="wp-image-41"/></a></figure></li>',
						'<li class="blocks-gallery-item"><figure><a href="' . get_theme_file_uri() . '/images/compact-gallery3.jpg"><img src="' . get_theme_file_uri() . '/images/compact-gallery3.jpg" alt="" data-id="42" data-full-url="' . get_theme_file_uri() . '/images/compact-gallery3.jpg" data-link="' . site_url() . '/home/compact-gallery3/" class="wp-image-42"/></a></figure></li>',
						'<li class="blocks-gallery-item"><figure><a href="' . get_theme_file_uri() . '/images/compact-gallery2.jpg"><img src="' . get_theme_file_uri() . '/images/compact-gallery2.jpg" alt="" data-id="43" data-full-url="' . get_theme_file_uri() . '/images/compact-gallery2.jpg" data-link="' . site_url() . '/home/compact-gallery2/" class="wp-image-43"/></a></figure></li>',
						'<li class="blocks-gallery-item"><figure><a href="' . get_theme_file_uri() . '/images/compact-gallery.jpg"><img src="' . get_theme_file_uri() . '/images/compact-gallery.jpg" alt="" data-id="44" data-full-url="' . get_theme_file_uri() . '/images/compact-gallery.jpg" data-link="' . site_url() . '/home/compact-gallery/" class="wp-image-44"/></a></figure></li>',
						'</ul></figure>',
						'<!-- /wp:gallery -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:cover {"customGradient":"linear-gradient(336deg,rgb(69,163,199) 0%,rgb(58,101,145) 100%)","align":"full"} -->',
						'<div class="wp-block-cover alignfull has-background-dim has-background-gradient" style="background:linear-gradient(336deg,rgb(69,163,199) 0%,rgb(58,101,145) 100%)">',
						'<div class="wp-block-cover__inner-container"><!-- wp:spacer {"height":30} -->',
						'<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:columns -->',
						'<div class="wp-block-columns"><!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:paragraph {"align":"center","customFontSize":68} -->',
						'<p style="font-size:68px" class="has-text-align-center"><strong>100</strong></p>',
						'<!-- /wp:paragraph -->',
						'<!-- wp:paragraph {"align":"center","textColor":"button-hover-text-color","fontSize":"normal"} -->',
						'<p class="has-text-color has-text-align-center has-normal-font-size has-button-hover-text-color-color">HAPPY CLIENTS</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:paragraph {"align":"center","customFontSize":68} -->',
						'<p style="font-size:68px" class="has-text-align-center"><strong>75</strong></p>',
						'<!-- /wp:paragraph -->',
						'<!-- wp:paragraph {"align":"center","fontSize":"normal"} -->',
						'<p class="has-text-align-center has-normal-font-size">Projects</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:paragraph {"align":"center","customFontSize":68} -->',
						'<p style="font-size:68px" class="has-text-align-center"><strong>95</strong></p>',
						'<!-- /wp:paragraph -->',
						'<!-- wp:paragraph {"align":"center","fontSize":"normal"} -->',
						'<p class="has-text-align-center has-normal-font-size">Members</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:paragraph {"align":"center","customFontSize":68} -->',
						'<p style="font-size:68px" class="has-text-align-center"><strong>88</strong></p>',
						'<!-- /wp:paragraph -->',
						'<!-- wp:paragraph {"align":"center","fontSize":"normal"} -->',
						'<p class="has-text-align-center has-normal-font-size">Awards</p>',
						'<!-- /wp:paragraph --></div>',
						'<!-- /wp:column --></div>',
						'<!-- /wp:columns -->',
						'<!-- wp:spacer {"height":30} -->',
						'<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:paragraph {"align":"center","placeholder":"Write title…","fontSize":"large"} -->',
						'<p class="has-text-align-center has-large-font-size"></p>',
						'<!-- /wp:paragraph --></div></div>',
						'<!-- /wp:cover -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:heading {"align":"center","level":1} -->',
						'<h1 class="has-text-align-center">Our Team</h1>',
						'<!-- /wp:heading -->',
						'<!-- wp:spacer {"height":30} -->',
						'<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
						'<!-- wp:columns -->',
						'<div class="wp-block-columns"><!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":38,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/team-compact2.jpg" alt="" class="wp-image-38"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4} -->',
						'<h4 class="has-text-align-center">Jane Doe</h4>',
						'<!-- /wp:heading --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":36,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/team-compact3.jpg" alt="" class="wp-image-36"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4} -->',
						'<h4 class="has-text-align-center">Richard Roe</h4>',
						'<!-- /wp:heading --></div>',
						'<!-- /wp:column -->',
						'<!-- wp:column -->',
						'<div class="wp-block-column"><!-- wp:image {"align":"center","id":35,"sizeSlug":"large"} -->',
						'<div class="wp-block-image"><figure class="aligncenter size-large"><img src="' . get_theme_file_uri() . '/images/team-compact4.jpg"" alt="" class="wp-image-35"/></figure></div>',
						'<!-- /wp:image -->',
						'<!-- wp:heading {"align":"center","level":4} -->',
						'<h4 class="has-text-align-center">John Doe</h4>',
						'<!-- /wp:heading --></div>',
						'<!-- /wp:column --></div>',
						'<!-- /wp:columns -->',
						'<!-- wp:spacer {"height":80} -->',
						'<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>',
						'<!-- /wp:spacer -->',
					)
				),
			),
			'about',
			'blog',
			'services',
			'contact',
		),

		// Default to a static front page and assign the front and posts pages.
		'options'    => array(
			'show_on_front'  => 'page',
			'page_on_front'  => '{{front}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set up nav menus for each of the two areas registered in the theme.
		'nav_menus'  => array(
			// Assign a menu to the "primary" location.
			'primary' => array(
				'name'  => __( 'Primary', 'compact-one' ),
				'items' => array(
					'link_home', // Note that the core "home" page is actually a link in case a static front page is not used.
					'page_about',
					'page_blog',
					'page_services',
					'page_contact',
				),
			),
		),

		// Custom setting.
		'theme_mods' => array(
			'responsive_transparent_header'               => 1,
			'responsive_disable_archive_transparent_header' => 1,
			'responsive_disable_blog_page_transparent_header' => 1,
			'responsive_disable_pages_transparent_header' => 1,
			'responsive_disable_posts_transparent_header' => 1,
			'responsive_disable_woo_products_transparent_header' => 1,
		),
	);

	/**
	 * Filters Compact One array of starter content.
	 *
	 * @since Compact One 2.0.0
	 *
	 * @param array $starter_content Array of starter content.
	 */
	return apply_filters( 'compact_one_starter_content', $starter_content );

}
