<?php
/**
 * Title: Options customizer
 *
 * Description: Defines option fields for theme customizer.
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

add_action( 'customize_register', 'cyberchimps_customize' );
function cyberchimps_customize( $wp_customize ) {

	/**
	 * Class Cyberchimps_Form
	 *
	 * Creates a form input type with the option to add description and placeholders
	 */
	class Cyberchimps_Form extends WP_Customize_Control {

		public function render_content() {
			switch ( $this->type ) {
				case 'textarea':
					?>
					<label>
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						<textarea value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?> style="width: 97%; height: 200px;"></textarea>
					</label>
					<?php
					break;
			}
		}
	}


	class Cyberchimps_Posts_Category extends WP_Customize_Control {
		public $type = 'select';

		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<select <?php $this->link(); ?>>
					<?php
					foreach ( $this->choices as $value => $label ) {
						echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . esc_attr( $label ) . '</option>';
					}
					?>
				</select>
			</label>
			<?php
		}
	}

	/********** Class for background image option starts *************/
	class Cyberchimps_Background_Image extends WP_Customize_Control {
		public $type = 'radio';

		public function render_content() {
			?>
			<style>
				.images-radio-subcontainer img {
					margin-top: 5px;
					padding: 2px;
					border: 5px solid #eee;
				}

				.images-radio-subcontainer img.of-radio-img-selected {
					border: 5px solid #5DA7F2;
				}

				.images-radio-subcontainer img:hover {
					cursor: pointer;
					border: 5px solid #5DA7F2;
				}
				#accordion-section-cyberchimps_header_section .customize-control-image img{ width: auto;}
				#accordion-section-cyberchimps_social_media .images-skin-subcontainer img{ height: auto;}
			</style>

			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<em>
				<small><?php _e( 'make sure you have removed the image above before selecting one of these', 'compact-one' ); ?></small>
			</em>
			<?php
			foreach ( $this->choices as $value => $label ) :

				//if get theme mod background image has a value then we need to set cyberchimps bg to none
				$test_bg  = $this->value();
				$test_bg  = ( get_theme_mod( 'background_image' ) ) ? 'none' : $test_bg;
				$name     = '_customize-radio-' . $this->id;
				$selected = ( $test_bg == $value ) ? 'of-radio-img-selected' : '';
				?>
				<div class="images-radio-subcontainer">
					<label>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>"
																<?php
																$this->link();
																checked( $test_bg, $value );
						?>
						 style="display:none;"/>
						<img src="<?php echo esc_html( $label ); ?>" class="of-radio-img-img <?php echo esc_attr( $selected ); ?>" alt="<?php echo esc_attr( $value ) . '-background-image'; ?>" /><br/>
					</label>
				</div>
				<?php
			endforeach;
		}
	}

	/********** Class for background image option ends *************/

	/********** Class for skin color selection option starts *************/
	class Cyberchimps_skin_selector extends WP_Customize_Control {
		public $type = 'radio';

		public function render_content() {
			?>
			<style>
				.images-skin-subcontainer, .images-radio-subcontainer {
					display: inline-block;
				}

				#customize-control-cyberchimps_background em {
					display: block;
				}

				.images-skin-subcontainer img {
					margin-top: 5px;
					padding: 2px;
					border: 5px solid #eee;
					width: 80px;
				}

				.images-skin-subcontainer img.of-radio-img-selected {
					border: 5px solid #5DA7F2;
				}

				.images-skin-subcontainer img:hover {
					cursor: pointer;
					border: 5px solid #5DA7F2;
				}
				#accordion-section-cyberchimps_header_section .customize-control-image img{ width: auto;}
				#accordion-section-cyberchimps_social_media .images-skin-subcontainer img{ height: auto;}
			</style>

			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php
			foreach ( $this->choices as $value => $label ) :

				//if get theme mod background image has a value then we need to set cyberchimps bg to none
				$test_skin = $this->value();
				$name      = '_customize-radio-' . $this->id;
				$selected  = ( $test_skin == $value ) ? 'of-radio-img-selected' : '';
				?>
				<div class="images-skin-subcontainer">
					<label>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>"
																<?php
																$this->link();
																checked( $test_skin, $value );
						?>
						 style="display:none;"/>
						<img src="<?php echo esc_html( $label ); ?>" class="of-radio-img-img <?php echo esc_attr( $selected ); ?>" alt="<?php echo esc_attr( $value ) . '-skin'; ?>" />
					</label>
				</div>
				<?php
			endforeach;
		}
	}


    /* --------------------------------------------------------------
    // FOOTER SECTION
    -------------------------------------------------------------- */
    $wp_customize->add_panel(
        'cyberchimps_compact_one_footer', array(
            'priority' => 46,
            'capability' => 'edit_theme_options',
            'theme_supports' => '',
            'title' => esc_html( __( 'Compact One Footer', 'compact-one' ) ),
        )
    );

    /* --------------------------------------------------------------
    // SOCIAL MEDIA SECTION
    -------------------------------------------------------------- */
			$wp_customize->add_section(
				'cyberchimps_social_media', array(
					'priority' => 60,
					'capability' => 'edit_theme_options',
					'theme_supports' => '',
					'title' => __( 'Social Options', 'compact-one' ),
                    'panel' => 'cyberchimps_compact_one_footer'
				)
			);

			//Select social Icon Style
			$social_choices = apply_filters(
				'cyberchimps_social_icon_options', array(
					'default' => get_stylesheet_directory_uri(). '/images/social/thumbs/icons-default.png',
					'legacy' => get_stylesheet_directory_uri(). '/images/social/thumbs/icons-classic.png',
					'round' => get_stylesheet_directory_uri(). '/images/social/thumbs/icons-round.png',
				)
			);
			if ( count( $social_choices ) > 1 ) {
				$wp_customize->add_setting(
					'theme_backgrounds', array(
						'default' => apply_filters( 'cyberchimps_social_icon_default', 'default' ),
						'sanitize_callback' => 'cyberchimps_text_sanitization',
					)
				);

				$wp_customize->add_control(
					new Cyberchimps_skin_selector(
						$wp_customize, 'theme_backgrounds', array(
							'label' => __( 'Choose your icon style', 'compact-one' ),
							'section' => 'cyberchimps_social_media',
							'settings' => 'theme_backgrounds',
							'choices' => $social_choices,
						)
					)
				);
			}
			// Add Facebook Setting
			$wp_customize->add_setting(
				'social_facebook', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_facebook', array(
						'label' => __( 'Display Facebook?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_facebook',
						'type' => 'checkbox',
					)
				)
			);

			$wp_customize->add_setting(
				'facebook_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'facebook_url', array(
						'label' => __( 'Facebook URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'facebook_url',
					)
				)
			);

			// Add Twitter Setting
			$wp_customize->add_setting(
				'social_twitter', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_twitter', array(
						'label' => __( 'Display Twitter?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_twitter',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'twitter_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'twitter_url', array(
						'label' => __( 'Twitter URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'twitter_url',
					)
				)
			);

			// Add Google+ Setting
			$wp_customize->add_setting(
				'social_google', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_google', array(
						'label' => __( 'Display Google?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_google',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'google_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'google_url', array(
						'label' => __( 'Google+ URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'google_url',
					)
				)
			);

			// Add LinkedIn Setting
			$wp_customize->add_setting(
				'social_linkedin', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_linkedin', array(
						'label' => __( 'Display LinkedIn?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_linkedin',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'linkedin_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'linkedin_url', array(
						'label' => __( 'LinkedIn URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'linkedin_url',
					)
				)
			);

			// Add Youtube Setting
			$wp_customize->add_setting(
				'social_youtube', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_youtube', array(
						'label' => __( 'Display Youtube?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_youtube',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'youtube_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'youtube_url', array(
						'label' => __( 'Youtube URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'youtube_url',
					)
				)
			);

			// Add Flickr Setting
			$wp_customize->add_setting(
				'social_flickr', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_flickr', array(
						'label' => __( 'Display Flickr?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_flickr',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'flickr_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'flickr_url', array(
						'label' => __( 'Flickr URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'flickr_url',
					)
				)
			);

			// Add Pinterest Setting
			$wp_customize->add_setting(
				'social_pinterest', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_pinterest', array(
						'label' => __( 'Display Pinterest?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_pinterest',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'pinterest_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'pinterest_url', array(
						'label' => __( 'Pinterest URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'pinterest_url',
					)
				)
			);

			// Add GoogleMap Setting
			$wp_customize->add_setting(
				'social_googlemaps', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_googlemaps', array(
						'label' => __( 'Display Google Maps?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_googlemaps',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'googlemaps_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'googlemaps_url', array(
						'label' => __( 'Google Maps URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'googlemaps_url',
					)
				)
			);

			// Add Email Setting
			$wp_customize->add_setting(
				'social_email', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_email', array(
						'label' => __( 'Display Email?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_email',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'email_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'email_url', array(
						'label' => __( 'Email Address', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'email_url',
					)
				)
			);

			// Add RSS Setting
			$wp_customize->add_setting(
				'social_rss', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_rss', array(
						'label' => __( 'Display RSS?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_rss',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'rss_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'rss_url', array(
						'label' => __( 'RSS URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'rss_url',
					)
				)
			);

			// Add Instagram Setting
			$wp_customize->add_setting(
				'social_instagram', array(
					'sanitize_callback' => 'cyberchimps_sanitize_checkbox',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'social_instagram', array(
						'label' => __( 'Display Instagram?', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'social_instagram',
						'type' => 'checkbox',
					)
				)
			);
			$wp_customize->add_setting(
				'instagram_url', array(
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize, 'instagram_url', array(
						'label' => __( 'Instagram URL', 'compact-one' ),
						'section' => 'cyberchimps_social_media',
						'settings' => 'instagram_url',
					)
				)
			);


}

/**
 * Text field sanitization
 *
 * @param $text
 *
 * @return string
 */
function cyberchimps_text_sanitization( $text ) {
	return sanitize_text_field( $text );
}

/**
 * File sanitization
 *
 * @param $text
 *
 * @return string
 */
function cyberchimps_file_sanitization( $name ) {
	return sanitize_file_name( $name );
}
